@@ -9,7 +9,7 @@ mix = matrix(c(-10.13, -10.72, -11.39, -11.18, -10.81, -10.7, -10.54,
                -10.48, -9.93, -9.37, 11.59, 11.01, 10.59, 10.97, 11.52, 11.89, 
                11.73, 10.89, 11.05, 12.3), ncol=2, nrow=10)
 colnames(mix) = c('d13C','d15N')
-s_names=c('Source A','Source B','Source C','Source D')
+s_names = c("Zostera", "Grass", "U.lactuca", "Enteromorpha")
 s_means = matrix(c(-14, -15.1, -11.03, -14.44, 3.06, 7.05, 13.72, 5.96), ncol=2, nrow=4)
 s_sds = matrix(c(0.48, 0.38, 0.48, 0.43, 0.46, 0.39, 0.42, 0.48), ncol=2, nrow=4)
 c_means = matrix(c(2.63, 1.59, 3.41, 3.04, 3.28, 2.34, 2.14, 2.36), ncol=2, nrow=4)
@@ -42,6 +42,9 @@ simmr_out = simmr_mcmc(simmr_in)
 ## ------------------------------------------------------------------------
 summary(simmr_out,type='diagnostics')
 
+## ------------------------------------------------------------------------
+#plot(simmr_out,type='convergence')
+
 ## ------------------------------------------------------------------------
 summary(simmr_out,type='statistics')
 summary(simmr_out,type='quantiles')
@@ -52,34 +55,14 @@ plot(simmr_out,type='density')
 ## ----fig.align='center',fig.width=7, fig.height=5------------------------
 plot(simmr_out,type='matrix')
 
+## ----fig.align='center',fig.width=7, fig.height=5------------------------
+compare_sources(simmr_out,source_names=c('Zostera','U.lactuca'))
+
+## ----fig.align='center',fig.width=7, fig.height=5------------------------
+compare_sources(simmr_out,source_names=c('Zostera','U.lactuca','Enteromorpha'))
+
 ## ------------------------------------------------------------------------
-mix = matrix(c(10.22, 10.37, 10.44, 10.52, 10.19, 10.45, 9.91, 11.27, 
-               9.34, 11.68, 12.29, 11.04, 11.46, 11.73, 12.29, 11.79, 11.49, 
-               11.73, 11.1, 11.36, 12.19, 11.03, 11.21, 10.58, 11.61, 12.16, 
-               10.7, 11.47, 12.07, 11.75, 11.86, 12.33, 12.36, 11.13, 10.92, 
-               12.42, 10.95, 12.28, 11.04, 10.76, 10.99, 10.78, 11.07, 10.2, 
-               11.67, 7.53, 10.65, 10.58, 11.13, 7.73, 10.79, 10.47, 10.82, 
-               10.41, 11.1, 10.95, 10.76, 10.83, 10.25, 10.52, 9.94, 9.94, 11.61, 
-               10.65, 10.76, 11.11, 10.2, 11.27, 10.21, 10.88, 11.21, 11.36, 
-               10.75, 12.38, 11.16, 11.57, 10.79, 11.13, 10.72, 10.99, 10.38, 
-               10.95, 10.75, 10.75, 11.05, 10.66, 10.61, 10.9, 11.14, 10.33, 
-               10.83, 10.75, 9.18, 9.03, 9.05, 8.6, 8.29, 10.32, 10.28, 6.47, 
-               11.36, 10.75, 11.13, 11.37, 10.86, 10.54, 10.39, 10.66, 9.99, 
-               11.65, 11.02, 10.67, 8.15, 11.12, 10.95, 11.2, 10.76, 11.32, 
-               10.85, 11.74, 10.46, 10.93, 12.3, 10.67, 11.51, 10.56, 12.51, 
-               13.51, 11.98, 12.2, 10.48, 12.4, 13, 11.36, 12.08, 12.39, 12.28, 
-               12.6, 11.3, 11.1, 11.42, 11.49, 12, 13.35, 11.97, 13.35, 12.75, 
-               12.55, 12.3, 12.51, 12.61, 10.98, 11.82, 12.27, 12.11, 12.11, 
-               12.89, 12.99, 12.29, 11.89, 12.74, 12.29, 11.89, 10.56, 9.27, 
-               10.54, 10.97, 10.46, 10.56, 10.86, 10.9, 11.06, 10.76, 10.64, 
-               10.94, 10.85, 10.45, 11.15, 11.23, 11.16, 10.94, 11.2, 10.71, 
-               9.55, 8.6, 9.67, 8.17, 9.81, 10.94, 9.49, 9.46, 7.94, 9.77, 8.07, 
-               8.39, 8.95, 9.83, 8.51, 8.86, 7.93, 8, 8.33, 8, 9.39, 8.01, 7.59, 
-               8.26, 9.49, 8.23, 9.1, 8.21, 9.59, 9.37, 9.47, 8.6, 8.23, 8.39, 
-               8.24, 8.34, 8.36, 7.22, 7.13, 10.64, 8.06, 8.22, 8.92, 9.35, 
-               7.32, 7.66, 8.09, 7.3, 7.33, 7.33, 7.36, 7.49, 8.07, 8.84, 7.93, 
-               7.94, 8.74, 8.26, 9.63, 8.85, 7.55, 10.05, 8.23, 7.74, 9.12, 
-               7.33, 7.54, 8.8, -11.36, -11.88, -10.6, -11.25, -11.66, -10.41, 
+mix = matrix(c(-11.36, -11.88, -10.6, -11.25, -11.66, -10.41, 
                -10.88, -14.73, -11.52, -15.89, -14.79, -17.64, -16.97, -17.25, 
                -14.77, -15.67, -15.34, -15.53, -17.27, -15.63, -15.94, -14.88, 
                -15.9, -17.11, -14.93, -16.26, -17.5, -16.37, -15.21, -15.43, 
@@ -110,15 +93,41 @@ mix = matrix(c(10.22, 10.37, 10.44, 10.52, 10.19, 10.45, 9.91, 11.27,
                -20.32, -28.21, -26.3, -28.27, -27.75, -28.55, -27.38, -29.13, 
                -28.66, -29.02, -26.04, -26.06, -28.52, -28.51, -27.93, -29.07, 
                -28.41, -26.42, -27.71, -27.75, -24.28, -28.43, -25.94, -28, 
-               -28.59, -22.61, -27.34, -27.35, -29.14), ncol=2, nrow=251)
+               -28.59, -22.61, -27.34, -27.35, -29.14, 10.22, 10.37, 10.44, 10.52, 10.19, 10.45, 9.91, 11.27, 
+               9.34, 11.68, 12.29, 11.04, 11.46, 11.73, 12.29, 11.79, 11.49, 
+               11.73, 11.1, 11.36, 12.19, 11.03, 11.21, 10.58, 11.61, 12.16, 
+               10.7, 11.47, 12.07, 11.75, 11.86, 12.33, 12.36, 11.13, 10.92, 
+               12.42, 10.95, 12.28, 11.04, 10.76, 10.99, 10.78, 11.07, 10.2, 
+               11.67, 7.53, 10.65, 10.58, 11.13, 7.73, 10.79, 10.47, 10.82, 
+               10.41, 11.1, 10.95, 10.76, 10.83, 10.25, 10.52, 9.94, 9.94, 11.61, 
+               10.65, 10.76, 11.11, 10.2, 11.27, 10.21, 10.88, 11.21, 11.36, 
+               10.75, 12.38, 11.16, 11.57, 10.79, 11.13, 10.72, 10.99, 10.38, 
+               10.95, 10.75, 10.75, 11.05, 10.66, 10.61, 10.9, 11.14, 10.33, 
+               10.83, 10.75, 9.18, 9.03, 9.05, 8.6, 8.29, 10.32, 10.28, 6.47, 
+               11.36, 10.75, 11.13, 11.37, 10.86, 10.54, 10.39, 10.66, 9.99, 
+               11.65, 11.02, 10.67, 8.15, 11.12, 10.95, 11.2, 10.76, 11.32, 
+               10.85, 11.74, 10.46, 10.93, 12.3, 10.67, 11.51, 10.56, 12.51, 
+               13.51, 11.98, 12.2, 10.48, 12.4, 13, 11.36, 12.08, 12.39, 12.28, 
+               12.6, 11.3, 11.1, 11.42, 11.49, 12, 13.35, 11.97, 13.35, 12.75, 
+               12.55, 12.3, 12.51, 12.61, 10.98, 11.82, 12.27, 12.11, 12.11, 
+               12.89, 12.99, 12.29, 11.89, 12.74, 12.29, 11.89, 10.56, 9.27, 
+               10.54, 10.97, 10.46, 10.56, 10.86, 10.9, 11.06, 10.76, 10.64, 
+               10.94, 10.85, 10.45, 11.15, 11.23, 11.16, 10.94, 11.2, 10.71, 
+               9.55, 8.6, 9.67, 8.17, 9.81, 10.94, 9.49, 9.46, 7.94, 9.77, 8.07, 
+               8.39, 8.95, 9.83, 8.51, 8.86, 7.93, 8, 8.33, 8, 9.39, 8.01, 7.59, 
+               8.26, 9.49, 8.23, 9.1, 8.21, 9.59, 9.37, 9.47, 8.6, 8.23, 8.39, 
+               8.24, 8.34, 8.36, 7.22, 7.13, 10.64, 8.06, 8.22, 8.92, 9.35, 
+               7.32, 7.66, 8.09, 7.3, 7.33, 7.33, 7.36, 7.49, 8.07, 8.84, 7.93, 
+               7.94, 8.74, 8.26, 9.63, 8.85, 7.55, 10.05, 8.23, 7.74, 9.12, 
+               7.33, 7.54, 8.8), ncol=2, nrow=251)
 colnames(mix) = c('d13C','d15N')
 s_names = c("Zostera", "Grass", "U.lactuca", "Enteromorpha")
-s_means = matrix(c(6.49, 4.43, 11.19, 9.82, -11.17, -30.88, -11.17, 
-                   -14.06), ncol=2, nrow=4)
-s_sds = matrix(c(1.46, 2.27, 1.11, 0.83, 1.21, 0.64, 1.96, 1.17), ncol=2, nrow=4)
-c_means = matrix(c(3.54, 3.54, 3.54, 3.54, 1.63, 1.63, 1.63, 1.63), ncol=2, nrow=4)
-c_sds = matrix(c(0.74, 0.74, 0.74, 0.74, 0.63, 0.63, 0.63, 0.63), ncol=2, nrow=4)
-conc = matrix(c(0.03, 0.04, 0.02, 0.01, 0.36, 0.4, 0.21, 0.18), ncol=2, nrow=4)
+s_means = matrix(c(-11.17, -30.88, -11.17, 
+                   -14.06, 6.49, 4.43, 11.19, 9.82), ncol=2, nrow=4)
+s_sds = matrix(c(1.21, 0.64, 1.96, 1.17, 1.46, 2.27, 1.11, 0.83), ncol=2, nrow=4)
+c_means = matrix(c(1.63, 1.63, 1.63, 1.63, 3.54, 3.54, 3.54, 3.54), ncol=2, nrow=4)
+c_sds = matrix(c(0.63, 0.63, 0.63, 0.63, 0.74, 0.74, 0.74, 0.74), ncol=2, nrow=4)
+conc = matrix(c(0.36, 0.4, 0.21, 0.18, 0.03, 0.04, 0.02, 0.01), ncol=2, nrow=4)
 grp = as.integer(c(1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
         2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 
         3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 
@@ -145,7 +154,7 @@ simmr_groups = simmr_load(mixtures=mix,
 ## ----fig.align='center',fig.width=7, fig.height=5------------------------
 plot(simmr_groups,group=1:8,xlab=expression(paste(delta^13, "C (\u2030)",sep="")), 
      ylab=expression(paste(delta^15, "N (\u2030)",sep="")), 
-     title='Isospace plot of Inger et al Geese data')
+     title='Isospace plot of Inger et al Geese data',mix_name='Geese')
 
 ## ----results='hide'------------------------------------------------------
 simmr_groups_out = simmr_mcmc(simmr_groups)
@@ -157,7 +166,7 @@ summary(simmr_groups_out,type=c('quantiles','statistics'),group=c(1,3))
 
 ## ----fig.align='center',fig.width=7, fig.height=5------------------------
 plot(simmr_groups_out,type='boxplot',group=2,title='simmr output group 2')
-plot(simmr_groups_out,type=c('density','matrix'),grp=6,title='simmr output group 6')
+plot(simmr_groups_out,type=c('density','matrix'),group=6,title='simmr output group 6')
 
 ## ----fig.align='center',fig.width=7, fig.height=5------------------------
 compare_groups(simmr_groups_out,source='Zostera',groups=1:2)
@@ -165,6 +174,21 @@ compare_groups(simmr_groups_out,source='Zostera',groups=1:2)
 ## ----fig.align='center',fig.width=7, fig.height=5------------------------
 compare_groups(simmr_groups_out,source='Zostera',groups=1:3)
 
+## ----fig.align='center',fig.width=7, fig.height=5------------------------
+simmr_out_combine = combine_sources(simmr_out,
+                                    to_combine=c('U.lactuca','Enteromorpha'),
+                                    new_source_name='U.lac+Ent')
+plot(simmr_out_combine$input)
+plot(simmr_out_combine,type='boxplot',title='simmr output: combined sources')
+
+## ----fig.align='center',fig.width=7, fig.height=5------------------------
+simmr_groups_out_combine = combine_sources(simmr_groups_out,
+                                           to_combine=c('U.lactuca','Enteromorpha'),
+                                           new_source_name='U.Lac+Ent')
+plot(simmr_groups_out_combine$input,group=1:8)
+plot(simmr_groups_out_combine,type='boxplot',title='simmr output: combined sources',group=8)
+plot(simmr_groups_out_combine,type='matrix',title='simmr output: combined sources',group=8)
+
 ## ----eval=FALSE----------------------------------------------------------
 #  str(simmr_in)
 
